@@ -88,8 +88,8 @@ LATN_TO_HIRA = {
 
     'rya': 'りゃ', 'ryu': 'りゅ', 'ryo': 'りょ',
 
-    'che': 'ちぇ', 'fa': 'ふぁ', 'vu': 'ヴ', 'fi': 'ふぃ', 'we': 'うぇ',
-    'fo': 'ふぉ',
+    'che': 'ちぇ', 'fa': 'ふぁ', 'vu': 'ゔ', 'fi': 'ふぃ', 'we': 'うぇ',
+    'fo': 'ふぉ', 'fe': 'ふぇ', 'wi': 'うぃ', 'je': 'じぇ',
 
     '-': 'ー', ':': 'ー',
     'n': 'ん', 'm': 'ん', "n'": 'ん',
